@@ -1,9 +1,10 @@
 /*
   Copyright (c) 2007 Till Adam <adam@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -44,26 +45,24 @@
 #include <MessageViewer/MessageViewerUtil>
 
 #include <KConfig>
-
+#include <KConfigGroup>
 #include <KListWidgetSearchLine>
 #include <KMessageBox>
 #include <QPushButton>
-#include <QFileDialog>
-
 #include <QFileDialog>
 #include <QRegularExpression>
 
 using namespace MailCommon;
 
-QList<MailFilter *> FilterImporterExporter::readFiltersFromConfig(
-    const KSharedConfig::Ptr config, QStringList &emptyFilters)
+QVector<MailFilter *> FilterImporterExporter::readFiltersFromConfig(
+    const KSharedConfig::Ptr &config, QStringList &emptyFilters)
 {
     const KConfigGroup group = config->group("General");
 
     const int numFilters = group.readEntry("filters", 0);
 
     bool filterNeedUpdate = false;
-    QList<MailFilter *> filters;
+    QVector<MailFilter *> filters;
     for (int i = 0; i < numFilters; ++i) {
         const QString groupName = QStringLiteral("Filter #%1").arg(i);
 
@@ -95,7 +94,7 @@ QList<MailFilter *> FilterImporterExporter::readFiltersFromConfig(
     return filters;
 }
 
-void FilterImporterExporter::writeFiltersToConfig(const QList<MailFilter *> &filters, KSharedConfig::Ptr config, bool exportFiler)
+void FilterImporterExporter::writeFiltersToConfig(const QVector<MailFilter *> &filters, KSharedConfig::Ptr config, bool exportFiler)
 {
     // first, delete all filter groups:
     const QStringList filterGroups
@@ -131,7 +130,7 @@ public:
     }
 
     void warningInfoAboutInvalidFilter(const QStringList &emptyFilters) const;
-    QWidget *mParent;
+    QWidget *mParent = nullptr;
 };
 
 void FilterImporterExporter::Private::warningInfoAboutInvalidFilter(
@@ -158,7 +157,7 @@ FilterImporterExporter::~FilterImporterExporter()
     delete d;
 }
 
-QList<MailFilter *> FilterImporterExporter::importFilters(
+QVector<MailFilter *> FilterImporterExporter::importFilters(
     bool &canceled, FilterImporterExporter::FilterType type, const QString &filename)
 {
     QString fileName(filename);
@@ -206,7 +205,7 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
             fileName = QFileDialog::getOpenFileName(d->mParent, title, defaultPath);
             if (fileName.isEmpty()) {
                 canceled = true;
-                return QList<MailFilter *>(); // cancel
+                return QVector<MailFilter *>(); // cancel
             }
         }
         file.setFileName(fileName);
@@ -215,11 +214,11 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
                 d->mParent,
                 i18n("The selected file is not readable. "
                      "Your file access permissions might be insufficient."));
-            return QList<MailFilter *>();
+            return QVector<MailFilter *>();
         }
     }
 
-    QList<MailFilter *> imported;
+    QVector<MailFilter *> imported;
     QStringList emptyFilter;
 
     switch (type) {
@@ -242,7 +241,7 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
                 defaultPath = MailCommon::FilterImporterThunderbird::defaultSeaMonkeyFiltersSettingsPath();
             }
 
-            SelectThunderbirdFilterFilesDialog *selectThunderBirdFileDialog = new SelectThunderbirdFilterFilesDialog(defaultPath, d->mParent);
+            QPointer<SelectThunderbirdFilterFilesDialog> selectThunderBirdFileDialog = new SelectThunderbirdFilterFilesDialog(defaultPath, d->mParent);
             selectThunderBirdFileDialog->setStartDir(QUrl::fromLocalFile(defaultPath));
             if (selectThunderBirdFileDialog->exec()) {
                 const QStringList lstFiles = selectThunderBirdFileDialog->selectedFiles();
@@ -265,7 +264,7 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
             } else {
                 canceled = true;
                 delete selectThunderBirdFileDialog;
-                return QList<MailFilter *>();
+                return QVector<MailFilter *>();
             }
             delete selectThunderBirdFileDialog;
         } else {
@@ -275,7 +274,7 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
                     d->mParent,
                     i18n("The selected file is not readable. "
                          "Your file access permissions might be insufficient."));
-                return QList<MailFilter *>();
+                return QVector<MailFilter *>();
             }
 
             MailCommon::FilterImporterThunderbird *thunderBirdFilter = new MailCommon::FilterImporterThunderbird(&file);
@@ -348,16 +347,19 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
     d->warningInfoAboutInvalidFilter(emptyFilter);
     file.close();
 
-    FilterSelectionDialog dlg(d->mParent);
-    dlg.setFilters(imported);
-    if (dlg.exec() == QDialog::Accepted) {
-        return dlg.selectedFilters();
+    QPointer<FilterSelectionDialog> dlg = new FilterSelectionDialog(d->mParent);
+    dlg->setFilters(imported);
+    if (dlg->exec() == QDialog::Accepted) {
+        const QVector<MailFilter *> selected = dlg->selectedFilters();
+        delete dlg;
+        return selected;
     }
+    delete dlg;
     canceled = true;
-    return QList<MailFilter *>();
+    return QVector<MailFilter *>();
 }
 
-void FilterImporterExporter::exportFilters(const QList<MailFilter *> &filters, const QUrl &fileName, bool saveAll)
+void FilterImporterExporter::exportFilters(const QVector<MailFilter *> &filters, const QUrl &fileName, bool saveAll)
 {
     QUrl saveUrl;
     if (fileName.isEmpty()) {
@@ -379,7 +381,7 @@ void FilterImporterExporter::exportFilters(const QList<MailFilter *> &filters, c
         std::unique_ptr<FilterSelectionDialog> dlg(new FilterSelectionDialog(d->mParent));
         dlg->setFilters(filters);
         if (dlg->exec() == QDialog::Accepted && dlg) {
-            QList<MailFilter *> lst = dlg->selectedFilters();
+            QVector<MailFilter *> lst = dlg->selectedFilters();
             writeFiltersToConfig(lst, config, true);
             qDeleteAll(lst);
         }
