@@ -54,7 +54,7 @@ bool SearchRuleDate::matches(const Akonadi::Item &item) const
         QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>")
                        : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msg += FilterLog::recode(asString());
-        msg += QStringLiteral(" ( <i>") + contents() + QStringLiteral("</i> )"); //TODO change with locale?
+        msg += QLatin1String(" ( <i>") + contents() + QLatin1String("</i> )"); //TODO change with locale?
         FilterLog::instance()->add(msg, FilterLog::RuleResult);
     }
     return rc;
